==> eiffelstudio-18.07.10.1981.tar: F_code/C72/re3563.c <==
/*
 * Code for class RESIZABLE [REAL_64]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "re3563.h"
#include "eif_helpers.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {RESIZABLE}.additional_space */
EIF_INTEGER_32 F793_8268 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R7481[Dtype(Current)-816])(Current);
	Result = eif_max_int32 ((EIF_INTEGER_32) (ti4_1 / ((EIF_INTEGER_32) 2L)),((EIF_INTEGER_32) 5L));
	RTLE;
	return Result;
}

/* {RESIZABLE}.automatic_grow */
void F793_8270 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R7481[dtype-816])(Current);
	{
		/* INLINED CODE (additional_space) */
		ti4_2 = (EIF_INTEGER_32)  0;
		ti4_3 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R7481[Dtype(Current)-816])(Current);
		ti4_2 = eif_max_int32 ((EIF_INTEGER_32) (ti4_3 / ((EIF_INTEGER_32) 2L)),((EIF_INTEGER_32) 5L));
		/* END INLINED CODE */
	}
	ti4_3 = ti4_2;
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32)) R7487[dtype-816])(Current, (EIF_INTEGER_32) (ti4_1 + ti4_3));
	RTLE;
}

void EIF_Minit3563 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-23.09.10.7341.tar: F_code/C72/re3563.c <==
/*
 * Code for class RESIZABLE [CHARACTER_32]
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "re3563.h"
#include "eif_helpers.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {RESIZABLE}.additional_space */
EIF_INTEGER_32 F1515_16073 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R13831[Dtype(Current)-1544])(Current);
	Result = eif_max_int32 ((EIF_INTEGER_32) (ti4_1 / ((EIF_INTEGER_32) 2L)),((EIF_INTEGER_32) 5L));
	RTLE;
	return Result;
}

/* {RESIZABLE}.automatic_grow */
void F1515_16075 (EIF_REFERENCE Current)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	RTCDT;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R13831[dtype-1544])(Current);
	{
		/* INLINED CODE (RESIZABLE.additional_space) */
		ti4_2 = (EIF_INTEGER_32)  0;
		ti4_3 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R13831[dtype-1544])(Current);
		ti4_2 = eif_max_int32 ((EIF_INTEGER_32) (ti4_3 / ((EIF_INTEGER_32) 2L)),((EIF_INTEGER_32) 5L));
		/* END INLINED CODE */
	}
	ti4_3 = ti4_2;
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32)) R13837[dtype-1544])(Current, (EIF_INTEGER_32) (ti4_1 + ti4_3));
	RTLE;
}

void EIF_Minit3563 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
